#
# spec file for package kdevelop5-plugin-python3
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define rname kdev-python
Name:           kdevelop5-plugin-python3
Version:        5.5.2
Release:        lp152.1.1
Summary:        Python support for KDevelop
License:        GPL-2.0-or-later
Group:          Development/Tools/IDE
URL:            https://www.kdevelop.org
Source0:        https://download.kde.org/stable/kdevelop/%{version}/src/%{rname}-%{version}.tar.xz
BuildRequires:  extra-cmake-modules
BuildRequires:  fdupes
BuildRequires:  kdevelop5
BuildRequires:  kdevplatform-devel
BuildRequires:  kf5-filesystem
BuildRequires:  ki18n-devel
BuildRequires:  ktexteditor-devel
BuildRequires:  pkgconfig
BuildRequires:  python3 >= 3.4.3
BuildRequires:  python3-devel >= 3.4.3
BuildRequires:  threadweaver-devel
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(Qt5Widgets)
Requires:       kdevelop5
Recommends:     %{name}-lang
Recommends:     python3-pep8
Provides:       kdevelop4-plugin-python = %{version}
Obsoletes:      kdevelop4-plugin-python < %{version}
# The following are needed due to old unstable packages in KDE repositories
Provides:       kdevelop4-plugin-python3 = %{version}
Obsoletes:      kdevelop4-plugin-python3 < %{version}

%description
A KDevelop plugin which provides Python language support, including code completion and debugging using PDB.

%package lang
Summary:        Translations for package %{name}
Group:          System/Localization
Requires:       %{name} = %{version}
Supplements:    packageand(bundle-lang-other:%{name})
Conflicts:      kdevelop4-plugin-python-lang
Provides:       %{name}-lang-all = %{version}
BuildArch:      noarch

%description lang
Provides translations to the package %{name}

%prep
%setup -q -n %{rname}-%{version}

%build
  %cmake_kf5 -d build
  make %{?_smp_mflags} parser
  %make_jobs

%install
  %kf5_makeinstall -C build
  %find_lang kdevpython %{name}.lang
  %fdupes -s %{buildroot}

%post   -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%license COPYING
%doc README
%{_kf5_appstreamdir}/org.kde.kdev-python.metainfo.xml
%{_kf5_debugdir}/kdevpythonsupport.categories
%{_kf5_libdir}/libkdev*python*.so*
%{_kf5_plugindir}/
%{_kf5_sharedir}/kdevappwizard/
%{_kf5_sharedir}/kdevpythonsupport/

%files lang -f %{name}.lang

%changelog
* Tue Jun  2 2020 wbauer@tmo.at
- Update to 5.5.2
  * No code changes
* Tue May  5 2020 wbauer@tmo.at
- Update to 5.5.1
  * No code changes
* Mon Feb  3 2020 wbauer@tmo.at
- Update to 5.5.0
  * Initial Python 3.8 support (kde#411956)
* Tue Jan  7 2020 wbauer@tmo.at
- Update to 5.4.6
  * No code changes
* Mon Dec  2 2019 wbauer@tmo.at
- Update to 5.4.5
  * No code changes
* Tue Nov  5 2019 wbauer@tmo.at
- Update to 5.4.4
  * No code changes
* Tue Oct 22 2019 wbauer@tmo.at
- Update to 5.4.3
  * No code changes
* Tue Sep  3 2019 wbauer@tmo.at
- Update to 5.4.2
  * no code changes
* Tue Aug 13 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.4.1
  * no code changes
* Tue Aug  6 2019 wbauer@tmo.at
- New upstream release 5.4.0
  * no code changes, just minor cleanups and adaptions to changes
    in the kdevplatform API
* Thu Jul 18 2019 wbauer@tmo.at
- New upstream release 5.3.3
  * Use KDE_INSTALL_LOGGINGCATEGORIESDIR for kdebugsettings
    .categories file
* Thu Mar  7 2019 wbauer@tmo.at
- New upstream release 5.3.2
  * Fix crash when finding context inside annotated assignments
    (kde#403045)
* Sat Dec 22 2018 wbauer@tmo.at
- New upstream release 5.3.1
  * Remove two outdated methods from shipped built-in documentation
- Run spec-cleaner
* Wed Nov 14 2018 wbauer@tmo.at
- New upstream release 5.3.0
  * Inject environment profile variables into debug process
    environment (kde#322477)
  * Improve support for 'with' statements (kde#399533, kde#399534)
- Remove unnecessary build requirements
* Tue Aug 21 2018 wbauer@tmo.at
- New upstream release 5.2.4
  * no code changes
* Fri May 25 2018 wbauer@tmo.at
- New upstream release 5.2.3 (5.2.2 has been skipped)
  * Ensure that codestyle.py always returns something on stdout to
    unlock m_mutex (kde#392031)
  * Fix crash with contexts opened in the baseclass list of a class
    definition (kde#389326)
  * Fix appstream metadata filename and some content, and install
    it
- New upstream release 5.2.1
  * no code changes
- New upstream release 5.2.0
  * For a list of changes, see:
    https://www.kdevelop.org/news/kdevelop-520-released
  * Fixed a false-positive warning when a name used in a closure
    was defined later in the file
  * Fixed highlighting of local variables in comprehensions and of
    parameters in lambda definitions
  * Infer the correct type when slicing a tuple with constant
    integers
  * Infer the correct type from 'and' or 'or' expressions
  * Internal code cleanups
- Remove superfluous python-qt5 requirement
- Install license file
* Tue Aug 29 2017 wbauer@tmo.at
- New upstream release 5.1.2
  * no code changes
* Sat May 27 2017 wbauer@tmo.at
- New upstream release 5.1.1
  * Fix crash (kde#378827)
  * Pep8: Make pep8 warnings less annoying
* Thu Mar 23 2017 wbauer@tmo.at
- New upstream release 5.1.0
  * For a list of changes, see:
    https://www.kdevelop.org/news/kdevelop-510-released
- Drop build-with-py36.diff, included upstream
- Adjust minimum python3 version, 3.4.3 and higher is supported now
* Sun Mar  5 2017 wbauer@tmo.at
- New upstream release 5.0.4
  * Update version number to 5.0.4
  * Fix crash when requesting raise items without the docfile being
    parsed (kde#373349)
- Rebase build-with-py36.diff
* Wed Feb 22 2017 lbeltrame@kde.org
- Add build-with-py36.diff: diff from upstream 50-python36 branch
  to enable building with Python 3.6
* Fri Dec  2 2016 wbauer@tmo.at
- New upstream release 5.0.3
  * Fix some small issues in the standard library info
* Wed Nov 16 2016 wbauer@tmo.at
- New upstream release 5.0.2
  * no code changes
* Tue Oct  4 2016 lbeltrame@kde.org
- Add QtConcurrent to BuildRequires
* Mon Oct  3 2016 lbeltrame@kde.org
- New upstream release 5.0.1
  * Fix imports sometimes not being found in kdev-python without
    pressing F5 by hand
* Fri Sep 23 2016 lbeltrame@kde.org
- Add conflicts with lang packages, to workaround a
  submission bot bug
* Wed Aug 24 2016 lbeltrame@kde.org
- Add Obsoletes/Provides for old kdevelop packages
* Wed Aug 24 2016 cgiboudeaux@gmx.com
- Update to 5.0.0
* Sat Mar 19 2016 fvogt@suse.com
- Fix build by removing wrong %%file entry
* Thu Jan 28 2016 tittiatcoke@gmail.com
- Initial package for Python3 plugin for KDevelop based on Frameworks
  * KDevelop 5 Beta 3
